@@ -412,6 +412,7 @@ file_query_info (GFile               *file,
         }
         else
         {
+            // This file is still in our favorites list but doesn't exist (currently).
             g_clear_error (error);
             gchar *content_type;
 
@@ -419,9 +420,10 @@ file_query_info (GFile               *file,
 
             g_file_info_set_display_name (info, priv->info->display_name);
             g_file_info_set_name (info, priv->info->display_name);
+            g_file_info_set_file_type (info, G_FILE_TYPE_SYMBOLIC_LINK);
             g_file_info_set_is_symlink (info, TRUE);
-
             g_file_info_set_symlink_target (info, priv->info->uri);
+            g_file_info_set_attribute_string (info, G_FILE_ATTRIBUTE_STANDARD_TARGET_URI, priv->info->uri);
 
             /* Prevent showing a 'thumbnailing' icon */
             g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_THUMBNAILING_FAILED, TRUE);
@@ -429,7 +431,6 @@ file_query_info (GFile               *file,
             /* This will keep the sort position the same for missing or unmounted files */
             g_file_info_set_attribute_string (info, FAVORITE_METADATA_KEY, META_TRUE);
             g_file_info_set_attribute_string (info, FAVORITE_AVAILABLE_METADATA_KEY, META_FALSE);
-            g_file_info_set_attribute_string (info, G_FILE_ATTRIBUTE_STANDARD_TARGET_URI, priv->info->uri);
 
             content_type = g_content_type_from_mime_type (priv->info->cached_mimetype);
 
@@ -540,6 +541,10 @@ file_query_filesystem_info (GFile         *file,
                             GError       **error)
 {
     FavoriteVfsFilePrivate *priv = favorite_vfs_file_get_instance_private (FAVORITE_VFS_FILE (file));
+    GFileInfo *info;
+    GFileAttributeMatcher *matcher;
+
+    matcher = g_file_attribute_matcher_new (attributes);
 
     if (priv->info != NULL && priv->info->uri != NULL)
     {
@@ -552,17 +557,18 @@ file_query_filesystem_info (GFile         *file,
                                              cancellable,
                                              error);
 
+        if (g_file_attribute_matcher_matches (matcher, G_FILE_ATTRIBUTE_FILESYSTEM_READONLY))
+        {
+            g_file_info_set_attribute_boolean (info,
+                                               G_FILE_ATTRIBUTE_FILESYSTEM_READONLY, TRUE);
+        }
+
         g_object_unref (real_file);
         return info;
     }
 
-    GFileInfo *info;
-    GFileAttributeMatcher *matcher;
-
     info = g_file_info_new ();
 
-    matcher = g_file_attribute_matcher_new (attributes);
-
     if (g_file_attribute_matcher_matches (matcher, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE))
     {
         g_file_info_set_attribute_string (info,
@@ -575,6 +581,13 @@ file_query_filesystem_info (GFile         *file,
                                            G_FILE_ATTRIBUTE_FILESYSTEM_READONLY, TRUE);
     }
 
+    if (g_file_attribute_matcher_matches (matcher, G_FILE_ATTRIBUTE_FILESYSTEM_USE_PREVIEW))
+    {
+        g_file_info_set_attribute_uint32 (info,
+                                          G_FILE_ATTRIBUTE_FILESYSTEM_USE_PREVIEW,
+                                          G_FILESYSTEM_PREVIEW_TYPE_IF_LOCAL);
+    }
+
     g_file_attribute_matcher_unref (matcher);
 
     return info;
@@ -969,36 +982,6 @@ file_append_to (GFile             *file,
     return NULL;
 }
 
-GFileOutputStream *
-file_create (GFile             *file,
-             GFileCreateFlags   flags,
-             GCancellable      *cancellable,
-             GError           **error)
-{
-    FavoriteVfsFilePrivate *priv = favorite_vfs_file_get_instance_private (FAVORITE_VFS_FILE (file));
-
-    if (priv->info != NULL && priv->info->uri != NULL)
-    {
-        GFile *real_file = g_file_new_for_uri (priv->info->uri);
-
-        GFileOutputStream *stream;
-
-        stream = g_file_create (real_file,
-                                flags,
-                                cancellable,
-                                error);
-
-        g_object_unref (real_file);
-        return stream;
-    }
-
-    g_set_error_literal (error, G_IO_ERROR,
-                         G_IO_ERROR_NOT_SUPPORTED,
-                        _("Operation not supported"));
-
-    return NULL;
-}
-
 static GFileOutputStream *
 file_replace (GFile             *file,
               const char        *etag,
@@ -1060,35 +1043,6 @@ file_open_readwrite (GFile                      *file,
     return NULL;
 }
 
-static GFileIOStream *
-file_create_readwrite (GFile                      *file,
-                       GFileCreateFlags            flags,
-                       GCancellable               *cancellable,
-                       GError                    **error)
-{
-    FavoriteVfsFilePrivate *priv = favorite_vfs_file_get_instance_private (FAVORITE_VFS_FILE (file));
-
-    if (priv->info != NULL && priv->info->uri != NULL)
-    {
-        GFileIOStream *res;
-        GFile *real_file = g_file_new_for_uri (priv->info->uri);
-
-        res = g_file_create_readwrite (real_file,
-                                       flags,
-                                       cancellable,
-                                       error);
-
-        g_object_unref (real_file);
-        return res;
-    }
-
-    g_set_error_literal (error, G_IO_ERROR,
-                         G_IO_ERROR_NOT_SUPPORTED,
-                        _("Operation not supported"));
-
-    return NULL;
-}
-
 static GFileIOStream *
 file_replace_readwrite (GFile                      *file,
                         const char                 *etag,
@@ -1129,17 +1083,18 @@ file_delete (GFile         *file,
 {
     FavoriteVfsFilePrivate *priv = favorite_vfs_file_get_instance_private (FAVORITE_VFS_FILE (file));
 
-    if (priv->info != NULL && priv->info->uri != NULL)
+    if (!is_root_file (FAVORITE_VFS_FILE (file)))
     {
-        gboolean res;
-        GFile *real_file = g_file_new_for_uri (priv->info->uri);
+        if (priv->info != NULL && priv->info->uri != NULL)
+        {
+            xapp_favorites_remove (xapp_favorites_get_default (), priv->info->uri);
+        }
+        else
+        {
+            xapp_favorites_remove (xapp_favorites_get_default (), priv->uri);
+        }
 
-        res = g_file_delete (real_file,
-                             cancellable,
-                             error);
-
-        g_object_unref (real_file);
-        return res;
+        return TRUE;
     }
 
     g_set_error_literal (error, G_IO_ERROR,
@@ -1154,30 +1109,11 @@ file_trash (GFile         *file,
             GCancellable  *cancellable,
             GError       **error)
 {
-    FavoriteVfsFilePrivate *priv = favorite_vfs_file_get_instance_private (FAVORITE_VFS_FILE (file));
-
-    if (priv->info != NULL && priv->info->uri != NULL)
-    {
-        gboolean res;
-        GFile *real_file = g_file_new_for_uri (priv->info->uri);
-
-        res = g_file_trash (real_file,
-                            cancellable,
-                            error);
-        g_object_unref (real_file);
-
-        return res;
-    }
-
-    g_set_error_literal (error, G_IO_ERROR,
-                         G_IO_ERROR_NOT_SUPPORTED,
-                         "Not supported");
-
-    return FALSE;
+    return file_delete (file, cancellable, error);
 }
 
 gboolean
-file_move (GFile                  *source,
+file_copy (GFile                  *source,
            GFile                  *destination,
            GFileCopyFlags          flags,
            GCancellable           *cancellable,
@@ -1192,7 +1128,7 @@ file_move (GFile                  *source,
         gboolean res;
         GFile *real_file = g_file_new_for_uri (priv->info->uri);
 
-        res = g_file_move (real_file,
+        res = g_file_copy (real_file,
                            destination,
                            flags,
                            cancellable,
@@ -1343,16 +1279,16 @@ static void favorite_vfs_file_gfile_iface_init (GFileIface *iface)
     iface->set_attributes_from_info = file_set_attributes_from_info;
     iface->read_fn = file_read_fn;
     iface->append_to = file_append_to;
-    iface->create = file_create;
+    // iface->create = file_create; ### Don't support
     iface->replace = file_replace;
     iface->open_readwrite = file_open_readwrite;
-    iface->create_readwrite = file_create_readwrite;
+    // iface->create_readwrite = file_create_readwrite; ### Don't support
     iface->replace_readwrite = file_replace_readwrite;
     iface->delete_file = file_delete;
     iface->trash = file_trash;
     // iface->make_directory = file_make_directory; ### Don't support
     // iface->make_symbolic_link = file_make_symbolic_link; ### Don't support
-    iface->move = file_move;
+    iface->copy = file_copy;
     iface->monitor_dir = file_monitor_dir;
     iface->monitor_file = file_monitor_file;
     iface->measure_disk_usage = file_measure_disk_usage;
