@@ -294,6 +294,8 @@ surface_from_pixmap_data (gint          width,
 
         return surface;
     }
+
+    return NULL;
 }
 
 static cairo_surface_t *
@@ -323,7 +325,7 @@ get_icon_surface (SnItem    *item,
 
     while (g_variant_iter_loop (iter, "(ii@ay)", &width, &height, &byte_array_var))
     {
-        if (width > 0 & height > 0 && byte_array_var != NULL &&
+        if (width > 0 && height > 0 && byte_array_var != NULL &&
             ((width * height) > (largest_width * largest_height)))
         {
             gsize data_size = g_variant_get_size (byte_array_var);
@@ -393,6 +395,11 @@ set_icon_from_pixmap (SnItem *item, SnItemPropertiesResult *new_props)
         {
             surface = new_props->attention_icon_surface;
         }
+        else
+        if (new_props->icon_surface)
+        {
+            surface = new_props->icon_surface;
+        }
     }
 
     if (surface != NULL)
@@ -423,9 +430,9 @@ set_icon_from_pixmap (SnItem *item, SnItemPropertiesResult *new_props)
 }
 
 static gchar *
-get_icon_filename_from_theme (SnItem      *item,
-                              const gchar *theme_path,
-                              const gchar *icon_name)
+get_name_or_path_from_theme (SnItem      *item,
+                             const gchar *theme_path,
+                             const gchar *icon_name)
 {
     GtkIconInfo *info;
     gchar *filename;
@@ -435,7 +442,7 @@ get_icon_filename_from_theme (SnItem      *item,
     array[0] = icon_name;
     array[1] = NULL;
 
-    // We have a theme path, but try the system theme first
+    // We may have a theme path, but try the system theme first
     GtkIconTheme *theme = gtk_icon_theme_get_default ();
     host_icon_size = get_icon_size (item);
 
@@ -445,7 +452,15 @@ get_icon_filename_from_theme (SnItem      *item,
                                                  lookup_ui_scale (),
                                                  GTK_ICON_LOOKUP_FORCE_SVG | GTK_ICON_LOOKUP_FORCE_SYMBOLIC);
 
-    if (info == NULL)
+    if (info != NULL)
+    {
+        // If the icon is found in the system theme, we can just pass along the icon name
+        // as is, this way symbolics work properly.
+        g_object_unref (info);
+        return g_strdup (icon_name);
+    }
+
+    if (theme_path != NULL)
     {
         // Make a temp theme based off of the provided path
         GtkIconTheme *theme = gtk_icon_theme_new ();
@@ -477,8 +492,10 @@ set_icon_name (SnItem      *item,
                const gchar *icon_theme_path,
                const gchar *icon_name)
 {
-    g_debug ("Checking for icon name for %s",
-             item->sortable_name);
+    g_debug ("Checking for icon name for %s - theme path: '%s', icon name: '%s'",
+             item->sortable_name,
+             icon_theme_path,
+             icon_name);
 
     if (icon_name == NULL)
     {
@@ -488,17 +505,16 @@ set_icon_name (SnItem      *item,
     if (g_path_is_absolute (icon_name))
     {
         xapp_status_icon_set_icon_name (item->status_icon, icon_name);
-
         return TRUE;
     }
     else
     {
-        gchar *filename = get_icon_filename_from_theme (item, icon_theme_path, icon_name);
+        gchar *used_name = get_name_or_path_from_theme (item, icon_theme_path, icon_name);
 
-        if (filename != NULL)
+        if (used_name != NULL)
         {
-            xapp_status_icon_set_icon_name (item->status_icon, filename);
-            g_free (filename);
+            xapp_status_icon_set_icon_name (item->status_icon, used_name);
+            g_free (used_name);
             return TRUE;
         }
     }
@@ -512,7 +528,10 @@ set_icon_name_or_path (SnItem                 *item,
 {
     const gchar *name_to_use = NULL;
 
-    if (item->status == STATUS_ACTIVE)
+    // Set an icon here, even if we're passive (hidden) - eventually only the
+    // status property might change, but we wouldn't have an icon then (unless
+    // the app sets the icon at the same time).
+    if (item->status == STATUS_ACTIVE || item->status == STATUS_PASSIVE)
     {
         if (new_props->icon_name)
         {
@@ -717,7 +736,7 @@ get_all_properties_callback (GObject      *source_object,
     {
         if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
         {
-            g_critical ("Could get propertyies for %s: %s\n",
+            g_critical ("Could not get properties for %s: %s\n",
                         g_dbus_proxy_get_name (item->sn_item_proxy),
                         error->message);
         }
@@ -888,7 +907,7 @@ get_all_properties_callback (GObject      *source_object,
         update_menu (item, new_props);
     }
 
-    if (new_props->update_icon)
+    if (new_props->update_icon || new_props->update_status)
     {
         update_icon (item, new_props);
     }
